# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vt.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='vt.proto',
  package='Bsii.SolarFocus.Protobuf',
  syntax='proto3',
  serialized_options=b'\252\002\034Bsii.SolarFocus.Lib.Protobuf',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x08vt.proto\x12\x18\x42sii.SolarFocus.Protobuf\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xf1\x01\n\x12TagsIdentifierBase\x12;\n\x08tag_type\x18\x01 \x01(\x0e\x32).Bsii.SolarFocus.Protobuf.IdentifierTypes\x12\x41\n\x0etag_identifier\x18\x02 \x01(\x0b\x32\'.Bsii.SolarFocus.Protobuf.TagIdentifierH\x00\x12P\n\x16virtual_tag_identifier\x18\x03 \x01(\x0b\x32..Bsii.SolarFocus.Protobuf.VirtualTagIdentifierH\x00\x42\t\n\x07subtype\"\x1b\n\rTagIdentifier\x12\n\n\x02id\x18\x01 \x01(\x05\"l\n\x14VirtualTagIdentifier\x12\x13\n\x0bmodule_name\x18\x01 \x01(\t\x12\x13\n\x0boutput_name\x18\x02 \x01(\t\x12\x19\n\x0c\x66ield_object\x18\x03 \x01(\x05H\x00\x88\x01\x01\x42\x0f\n\r_field_object\"\xa6\x01\n\x15VirtualModuleInputTag\x12<\n\x06raw_id\x18\x01 \x01(\x0b\x32,.Bsii.SolarFocus.Protobuf.TagsIdentifierBase\x12\x10\n\x08tag_name\x18\x02 \x01(\t\x12\x13\n\x0bsource_name\x18\x03 \x01(\t\x12\x11\n\tsource_id\x18\x04 \x01(\x05\x12\x15\n\rvariable_name\x18\x05 \x01(\t\"\x82\x01\n\x12NumericTagMetadata\x12.\n\tmin_value\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12.\n\tmax_value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x0c\n\x04unit\x18\x03 \x01(\t\"\xc8\x01\n\rAlarmMetadata\x12\x39\n\x08severity\x18\x01 \x01(\x0e\x32\'.Bsii.SolarFocus.Protobuf.AlarmSeverity\x12\x39\n\x08\x63\x61tegory\x18\x02 \x01(\x0e\x32\'.Bsii.SolarFocus.Protobuf.AlarmCategory\x12\x41\n\x0e\x63omponent_type\x18\x03 \x01(\x0e\x32).Bsii.SolarFocus.Protobuf.FieldObjectType\"\x86\x02\n\x0bTagMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x42\n\x0f\x61laram_metadata\x18\x03 \x01(\x0b\x32\'.Bsii.SolarFocus.Protobuf.AlarmMetadataH\x00\x12L\n\x14numeric_tag_metadata\x18\x04 \x01(\x0b\x32,.Bsii.SolarFocus.Protobuf.NumericTagMetadataH\x00\x12\x36\n\x04type\x18\x05 \x01(\x0e\x32(.Bsii.SolarFocus.Protobuf.VirtualTagTypeB\n\n\x08metadata\"\xc6\x03\n\x11VirtualDataModule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x12\n\nbase_image\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tsite_name\x18\x05 \x01(\t\x12\x13\n\x0b\x65nvironment\x18\x06 \x01(\t\x12G\n\x12\x63\x61lculation_method\x18\x07 \x01(\x0e\x32+.Bsii.SolarFocus.Protobuf.CalculationMethod\x12\x33\n\x10sample_frequency\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x43\n\ninput_data\x18\t \x03(\x0b\x32/.Bsii.SolarFocus.Protobuf.VirtualModuleInputTag\x12:\n\x0boutput_data\x18\n \x03(\x0b\x32%.Bsii.SolarFocus.Protobuf.TagMetadata\x12\x41\n\x08\x63\x61tegory\x18\x0b \x01(\x0e\x32/.Bsii.SolarFocus.Protobuf.VirtualModuleCategory\"\xcf\x01\n\x0eValuePerObject\x12@\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x32.Bsii.SolarFocus.Protobuf.ValuePerObject.DataEntry\x12\x31\n\rtimestamp_utc\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1aH\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue:\x02\x38\x01\"\x86\x01\n\x05\x41larm\x12\x32\n\x0estart_time_utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x65nd_time_utc\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x61\x64\x64itional_data\x18\x03 \x01(\t\"\x9f\x02\n\tDataPoint\x12\x0f\n\x05value\x18\x01 \x01(\x02H\x00\x12\x16\n\x0cstring_value\x18\x02 \x01(\tH\x00\x12\x30\n\ntime_value\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x44\n\x10value_per_object\x18\x04 \x01(\x0b\x32(.Bsii.SolarFocus.Protobuf.ValuePerObjectH\x00\x12\x37\n\x05table\x18\x05 \x01(\x0b\x32&.Bsii.SolarFocus.Protobuf.DataFrameDtoH\x00\x12\x30\n\x05\x61larm\x18\x06 \x01(\x0b\x32\x1f.Bsii.SolarFocus.Protobuf.AlarmH\x00\x42\x06\n\x04\x64\x61ta\"\x8e\x02\n\nRowDataDto\x12\x33\n\rtimestamp_utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x16\n\x0cstring_index\x18\x02 \x01(\tH\x00\x12\x17\n\rnumeric_index\x18\x03 \x01(\x02H\x00\x12>\n\x05value\x18\x04 \x03(\x0b\x32/.Bsii.SolarFocus.Protobuf.RowDataDto.ValueEntry\x1aQ\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.Bsii.SolarFocus.Protobuf.DataPoint:\x02\x38\x01\x42\x07\n\x05index\"B\n\x0c\x44\x61taFrameDto\x12\x32\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32$.Bsii.SolarFocus.Protobuf.RowDataDto\"h\n\x13\x46ieldObjectMetadata\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x37\n\x04type\x18\x03 \x01(\x0e\x32).Bsii.SolarFocus.Protobuf.FieldObjectType\"\xe2\x01\n\x0cSiteMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\tlongitude\x18\x02 \x01(\x02H\x00\x88\x01\x01\x12\x15\n\x08latitude\x18\x03 \x01(\x02H\x01\x88\x01\x01\x12\x15\n\x08\x61ltitude\x18\x04 \x01(\x02H\x02\x88\x01\x01\x12\x1c\n\x0f\x63ontractor_name\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x16\n\tmax_power\x18\x06 \x01(\x02H\x04\x88\x01\x01\x42\x0c\n\n_longitudeB\x0b\n\t_latitudeB\x0b\n\t_altitudeB\x12\n\x10_contractor_nameB\x0c\n\n_max_power\"\xdd\x01\n\x14InputDataRequestArgs\x12\x32\n\x0estart_time_utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x65nd_time_utc\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11\x66ield_objects_ids\x18\x03 \x03(\x05\x12\x44\n\x0fmodule_metadata\x18\x04 \x01(\x0b\x32+.Bsii.SolarFocus.Protobuf.VirtualDataModule\"\xd5\x01\n\x0f\x44\x61taResponseDto\x12\x34\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32&.Bsii.SolarFocus.Protobuf.DataFrameDto\x12M\n\x16\x66ield_objects_metadata\x18\x02 \x03(\x0b\x32-.Bsii.SolarFocus.Protobuf.FieldObjectMetadata\x12=\n\rsite_metadata\x18\x03 \x01(\x0b\x32&.Bsii.SolarFocus.Protobuf.SiteMetadata*?\n\x15VirtualModuleCategory\x12\x0e\n\nTIMESERIES\x10\x00\x12\n\n\x06TABLES\x10\x01\x12\n\n\x06\x41LARMS\x10\x02*S\n\x0eVirtualTagType\x12\x13\n\x0fNUMERIC_CONTENT\x10\x00\x12\x16\n\x12NUMERIC_PER_OBJECT\x10\x01\x12\t\n\x05\x41LARM\x10\x02\x12\t\n\x05TABLE\x10\x03*\xae\x01\n\x11\x43\x61lculationMethod\x12\x08\n\x04NONE\x10\x00\x12\x16\n\x12LINEAR_INTERPOLATE\x10\x01\x12\x1c\n\x18\x41VERAGE_OVER_SAMPLE_FREQ\x10\x02\x12\x18\n\x14MAX_OVER_SAMPLE_FREQ\x10\x03\x12\x18\n\x14MIN_OVRR_SAMPLE_FREQ\x10\x04\x12\x11\n\rLEFT_NEIGHBOR\x10\x05\x12\x12\n\x0eRIGHT_NEIGHBOR\x10\x06*J\n\x0fIdentifierTypes\x12\x08\n\x04ZERO\x10\x00\x12\x0b\n\x07NUMERIC\x10\x01\x12\x13\n\x0fNUMERIC_PER_SFO\x10\x02\x12\x0b\n\x07VIRTUAL\x10\x03*I\n\rAlarmCategory\x12\t\n\x05\x43YBER\x10\x00\x12\x0f\n\x0bMAINTENANCE\x10\x01\x12\x0f\n\x0bPERFORMANCE\x10\x02\x12\x0b\n\x07GENERAL\x10\x03*5\n\rAlarmSeverity\x12\x0b\n\x07WARNING\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x0c\n\x08\x43RITICAL\x10\x02*\xa2\x01\n\x0f\x46ieldObjectType\x12\x11\n\rCSP_HELIOSTAT\x10\x00\x12\x10\n\x0c\x41\x43\x43\x45SS_POINT\x10\x01\x12\n\n\x06\x43\x41MERA\x10\x02\x12\x13\n\x0fWEATHER_STATION\x10\x03\x12\x0f\n\x0bPV_INVERTER\x10\x04\x12\x0b\n\x07PV_DCCB\x10\x05\x12\r\n\tPV_STRING\x10\x06\x12\x0e\n\nPV_TRACKER\x10\x07\x12\x0c\n\x08PV_METER\x10\x08\x32x\n\x10InputDataService\x12\x64\n\x07GetData\x12..Bsii.SolarFocus.Protobuf.InputDataRequestArgs\x1a).Bsii.SolarFocus.Protobuf.DataResponseDtoB\x1f\xaa\x02\x1c\x42sii.SolarFocus.Lib.Protobufb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])

_VIRTUALMODULECATEGORY = _descriptor.EnumDescriptor(
  name='VirtualModuleCategory',
  full_name='Bsii.SolarFocus.Protobuf.VirtualModuleCategory',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TIMESERIES', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TABLES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALARMS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3498,
  serialized_end=3561,
)
_sym_db.RegisterEnumDescriptor(_VIRTUALMODULECATEGORY)

VirtualModuleCategory = enum_type_wrapper.EnumTypeWrapper(_VIRTUALMODULECATEGORY)
_VIRTUALTAGTYPE = _descriptor.EnumDescriptor(
  name='VirtualTagType',
  full_name='Bsii.SolarFocus.Protobuf.VirtualTagType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NUMERIC_CONTENT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUMERIC_PER_OBJECT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALARM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TABLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3563,
  serialized_end=3646,
)
_sym_db.RegisterEnumDescriptor(_VIRTUALTAGTYPE)

VirtualTagType = enum_type_wrapper.EnumTypeWrapper(_VIRTUALTAGTYPE)
_CALCULATIONMETHOD = _descriptor.EnumDescriptor(
  name='CalculationMethod',
  full_name='Bsii.SolarFocus.Protobuf.CalculationMethod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINEAR_INTERPOLATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AVERAGE_OVER_SAMPLE_FREQ', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_OVER_SAMPLE_FREQ', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN_OVRR_SAMPLE_FREQ', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_NEIGHBOR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_NEIGHBOR', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3649,
  serialized_end=3823,
)
_sym_db.RegisterEnumDescriptor(_CALCULATIONMETHOD)

CalculationMethod = enum_type_wrapper.EnumTypeWrapper(_CALCULATIONMETHOD)
_IDENTIFIERTYPES = _descriptor.EnumDescriptor(
  name='IdentifierTypes',
  full_name='Bsii.SolarFocus.Protobuf.IdentifierTypes',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ZERO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUMERIC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUMERIC_PER_SFO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIRTUAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3825,
  serialized_end=3899,
)
_sym_db.RegisterEnumDescriptor(_IDENTIFIERTYPES)

IdentifierTypes = enum_type_wrapper.EnumTypeWrapper(_IDENTIFIERTYPES)
_ALARMCATEGORY = _descriptor.EnumDescriptor(
  name='AlarmCategory',
  full_name='Bsii.SolarFocus.Protobuf.AlarmCategory',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CYBER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAINTENANCE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERFORMANCE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GENERAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3901,
  serialized_end=3974,
)
_sym_db.RegisterEnumDescriptor(_ALARMCATEGORY)

AlarmCategory = enum_type_wrapper.EnumTypeWrapper(_ALARMCATEGORY)
_ALARMSEVERITY = _descriptor.EnumDescriptor(
  name='AlarmSeverity',
  full_name='Bsii.SolarFocus.Protobuf.AlarmSeverity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3976,
  serialized_end=4029,
)
_sym_db.RegisterEnumDescriptor(_ALARMSEVERITY)

AlarmSeverity = enum_type_wrapper.EnumTypeWrapper(_ALARMSEVERITY)
_FIELDOBJECTTYPE = _descriptor.EnumDescriptor(
  name='FieldObjectType',
  full_name='Bsii.SolarFocus.Protobuf.FieldObjectType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CSP_HELIOSTAT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCESS_POINT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAMERA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEATHER_STATION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PV_INVERTER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PV_DCCB', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PV_STRING', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PV_TRACKER', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PV_METER', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4032,
  serialized_end=4194,
)
_sym_db.RegisterEnumDescriptor(_FIELDOBJECTTYPE)

FieldObjectType = enum_type_wrapper.EnumTypeWrapper(_FIELDOBJECTTYPE)
TIMESERIES = 0
TABLES = 1
ALARMS = 2
NUMERIC_CONTENT = 0
NUMERIC_PER_OBJECT = 1
ALARM = 2
TABLE = 3
NONE = 0
LINEAR_INTERPOLATE = 1
AVERAGE_OVER_SAMPLE_FREQ = 2
MAX_OVER_SAMPLE_FREQ = 3
MIN_OVRR_SAMPLE_FREQ = 4
LEFT_NEIGHBOR = 5
RIGHT_NEIGHBOR = 6
ZERO = 0
NUMERIC = 1
NUMERIC_PER_SFO = 2
VIRTUAL = 3
CYBER = 0
MAINTENANCE = 1
PERFORMANCE = 2
GENERAL = 3
WARNING = 0
ERROR = 1
CRITICAL = 2
CSP_HELIOSTAT = 0
ACCESS_POINT = 1
CAMERA = 2
WEATHER_STATION = 3
PV_INVERTER = 4
PV_DCCB = 5
PV_STRING = 6
PV_TRACKER = 7
PV_METER = 8



_TAGSIDENTIFIERBASE = _descriptor.Descriptor(
  name='TagsIdentifierBase',
  full_name='Bsii.SolarFocus.Protobuf.TagsIdentifierBase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag_type', full_name='Bsii.SolarFocus.Protobuf.TagsIdentifierBase.tag_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag_identifier', full_name='Bsii.SolarFocus.Protobuf.TagsIdentifierBase.tag_identifier', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_tag_identifier', full_name='Bsii.SolarFocus.Protobuf.TagsIdentifierBase.virtual_tag_identifier', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='subtype', full_name='Bsii.SolarFocus.Protobuf.TagsIdentifierBase.subtype',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=136,
  serialized_end=377,
)


_TAGIDENTIFIER = _descriptor.Descriptor(
  name='TagIdentifier',
  full_name='Bsii.SolarFocus.Protobuf.TagIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Bsii.SolarFocus.Protobuf.TagIdentifier.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=379,
  serialized_end=406,
)


_VIRTUALTAGIDENTIFIER = _descriptor.Descriptor(
  name='VirtualTagIdentifier',
  full_name='Bsii.SolarFocus.Protobuf.VirtualTagIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='module_name', full_name='Bsii.SolarFocus.Protobuf.VirtualTagIdentifier.module_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_name', full_name='Bsii.SolarFocus.Protobuf.VirtualTagIdentifier.output_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_object', full_name='Bsii.SolarFocus.Protobuf.VirtualTagIdentifier.field_object', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_field_object', full_name='Bsii.SolarFocus.Protobuf.VirtualTagIdentifier._field_object',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=408,
  serialized_end=516,
)


_VIRTUALMODULEINPUTTAG = _descriptor.Descriptor(
  name='VirtualModuleInputTag',
  full_name='Bsii.SolarFocus.Protobuf.VirtualModuleInputTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_id', full_name='Bsii.SolarFocus.Protobuf.VirtualModuleInputTag.raw_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag_name', full_name='Bsii.SolarFocus.Protobuf.VirtualModuleInputTag.tag_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_name', full_name='Bsii.SolarFocus.Protobuf.VirtualModuleInputTag.source_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_id', full_name='Bsii.SolarFocus.Protobuf.VirtualModuleInputTag.source_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable_name', full_name='Bsii.SolarFocus.Protobuf.VirtualModuleInputTag.variable_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=685,
)


_NUMERICTAGMETADATA = _descriptor.Descriptor(
  name='NumericTagMetadata',
  full_name='Bsii.SolarFocus.Protobuf.NumericTagMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_value', full_name='Bsii.SolarFocus.Protobuf.NumericTagMetadata.min_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_value', full_name='Bsii.SolarFocus.Protobuf.NumericTagMetadata.max_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='Bsii.SolarFocus.Protobuf.NumericTagMetadata.unit', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=688,
  serialized_end=818,
)


_ALARMMETADATA = _descriptor.Descriptor(
  name='AlarmMetadata',
  full_name='Bsii.SolarFocus.Protobuf.AlarmMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='severity', full_name='Bsii.SolarFocus.Protobuf.AlarmMetadata.severity', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='Bsii.SolarFocus.Protobuf.AlarmMetadata.category', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='component_type', full_name='Bsii.SolarFocus.Protobuf.AlarmMetadata.component_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=821,
  serialized_end=1021,
)


_TAGMETADATA = _descriptor.Descriptor(
  name='TagMetadata',
  full_name='Bsii.SolarFocus.Protobuf.TagMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Bsii.SolarFocus.Protobuf.TagMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Bsii.SolarFocus.Protobuf.TagMetadata.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alaram_metadata', full_name='Bsii.SolarFocus.Protobuf.TagMetadata.alaram_metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numeric_tag_metadata', full_name='Bsii.SolarFocus.Protobuf.TagMetadata.numeric_tag_metadata', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Bsii.SolarFocus.Protobuf.TagMetadata.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='metadata', full_name='Bsii.SolarFocus.Protobuf.TagMetadata.metadata',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1024,
  serialized_end=1286,
)


_VIRTUALDATAMODULE = _descriptor.Descriptor(
  name='VirtualDataModule',
  full_name='Bsii.SolarFocus.Protobuf.VirtualDataModule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Bsii.SolarFocus.Protobuf.VirtualDataModule.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='Bsii.SolarFocus.Protobuf.VirtualDataModule.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_image', full_name='Bsii.SolarFocus.Protobuf.VirtualDataModule.base_image', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Bsii.SolarFocus.Protobuf.VirtualDataModule.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_name', full_name='Bsii.SolarFocus.Protobuf.VirtualDataModule.site_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='Bsii.SolarFocus.Protobuf.VirtualDataModule.environment', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calculation_method', full_name='Bsii.SolarFocus.Protobuf.VirtualDataModule.calculation_method', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_frequency', full_name='Bsii.SolarFocus.Protobuf.VirtualDataModule.sample_frequency', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_data', full_name='Bsii.SolarFocus.Protobuf.VirtualDataModule.input_data', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_data', full_name='Bsii.SolarFocus.Protobuf.VirtualDataModule.output_data', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='Bsii.SolarFocus.Protobuf.VirtualDataModule.category', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1289,
  serialized_end=1743,
)


_VALUEPEROBJECT_DATAENTRY = _descriptor.Descriptor(
  name='DataEntry',
  full_name='Bsii.SolarFocus.Protobuf.ValuePerObject.DataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Bsii.SolarFocus.Protobuf.ValuePerObject.DataEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Bsii.SolarFocus.Protobuf.ValuePerObject.DataEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1881,
  serialized_end=1953,
)

_VALUEPEROBJECT = _descriptor.Descriptor(
  name='ValuePerObject',
  full_name='Bsii.SolarFocus.Protobuf.ValuePerObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='Bsii.SolarFocus.Protobuf.ValuePerObject.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_utc', full_name='Bsii.SolarFocus.Protobuf.ValuePerObject.timestamp_utc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_VALUEPEROBJECT_DATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1746,
  serialized_end=1953,
)


_ALARM = _descriptor.Descriptor(
  name='Alarm',
  full_name='Bsii.SolarFocus.Protobuf.Alarm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time_utc', full_name='Bsii.SolarFocus.Protobuf.Alarm.start_time_utc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time_utc', full_name='Bsii.SolarFocus.Protobuf.Alarm.end_time_utc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_data', full_name='Bsii.SolarFocus.Protobuf.Alarm.additional_data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1956,
  serialized_end=2090,
)


_DATAPOINT = _descriptor.Descriptor(
  name='DataPoint',
  full_name='Bsii.SolarFocus.Protobuf.DataPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='Bsii.SolarFocus.Protobuf.DataPoint.value', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='Bsii.SolarFocus.Protobuf.DataPoint.string_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_value', full_name='Bsii.SolarFocus.Protobuf.DataPoint.time_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_per_object', full_name='Bsii.SolarFocus.Protobuf.DataPoint.value_per_object', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table', full_name='Bsii.SolarFocus.Protobuf.DataPoint.table', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alarm', full_name='Bsii.SolarFocus.Protobuf.DataPoint.alarm', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='Bsii.SolarFocus.Protobuf.DataPoint.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2093,
  serialized_end=2380,
)


_ROWDATADTO_VALUEENTRY = _descriptor.Descriptor(
  name='ValueEntry',
  full_name='Bsii.SolarFocus.Protobuf.RowDataDto.ValueEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Bsii.SolarFocus.Protobuf.RowDataDto.ValueEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Bsii.SolarFocus.Protobuf.RowDataDto.ValueEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2563,
  serialized_end=2644,
)

_ROWDATADTO = _descriptor.Descriptor(
  name='RowDataDto',
  full_name='Bsii.SolarFocus.Protobuf.RowDataDto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_utc', full_name='Bsii.SolarFocus.Protobuf.RowDataDto.timestamp_utc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_index', full_name='Bsii.SolarFocus.Protobuf.RowDataDto.string_index', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numeric_index', full_name='Bsii.SolarFocus.Protobuf.RowDataDto.numeric_index', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Bsii.SolarFocus.Protobuf.RowDataDto.value', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROWDATADTO_VALUEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='index', full_name='Bsii.SolarFocus.Protobuf.RowDataDto.index',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2383,
  serialized_end=2653,
)


_DATAFRAMEDTO = _descriptor.Descriptor(
  name='DataFrameDto',
  full_name='Bsii.SolarFocus.Protobuf.DataFrameDto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='Bsii.SolarFocus.Protobuf.DataFrameDto.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2655,
  serialized_end=2721,
)


_FIELDOBJECTMETADATA = _descriptor.Descriptor(
  name='FieldObjectMetadata',
  full_name='Bsii.SolarFocus.Protobuf.FieldObjectMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Bsii.SolarFocus.Protobuf.FieldObjectMetadata.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Bsii.SolarFocus.Protobuf.FieldObjectMetadata.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Bsii.SolarFocus.Protobuf.FieldObjectMetadata.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2723,
  serialized_end=2827,
)


_SITEMETADATA = _descriptor.Descriptor(
  name='SiteMetadata',
  full_name='Bsii.SolarFocus.Protobuf.SiteMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Bsii.SolarFocus.Protobuf.SiteMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='Bsii.SolarFocus.Protobuf.SiteMetadata.longitude', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='Bsii.SolarFocus.Protobuf.SiteMetadata.latitude', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='altitude', full_name='Bsii.SolarFocus.Protobuf.SiteMetadata.altitude', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contractor_name', full_name='Bsii.SolarFocus.Protobuf.SiteMetadata.contractor_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_power', full_name='Bsii.SolarFocus.Protobuf.SiteMetadata.max_power', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_longitude', full_name='Bsii.SolarFocus.Protobuf.SiteMetadata._longitude',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_latitude', full_name='Bsii.SolarFocus.Protobuf.SiteMetadata._latitude',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_altitude', full_name='Bsii.SolarFocus.Protobuf.SiteMetadata._altitude',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_contractor_name', full_name='Bsii.SolarFocus.Protobuf.SiteMetadata._contractor_name',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_max_power', full_name='Bsii.SolarFocus.Protobuf.SiteMetadata._max_power',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2830,
  serialized_end=3056,
)


_INPUTDATAREQUESTARGS = _descriptor.Descriptor(
  name='InputDataRequestArgs',
  full_name='Bsii.SolarFocus.Protobuf.InputDataRequestArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time_utc', full_name='Bsii.SolarFocus.Protobuf.InputDataRequestArgs.start_time_utc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time_utc', full_name='Bsii.SolarFocus.Protobuf.InputDataRequestArgs.end_time_utc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_objects_ids', full_name='Bsii.SolarFocus.Protobuf.InputDataRequestArgs.field_objects_ids', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_metadata', full_name='Bsii.SolarFocus.Protobuf.InputDataRequestArgs.module_metadata', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3059,
  serialized_end=3280,
)


_DATARESPONSEDTO = _descriptor.Descriptor(
  name='DataResponseDto',
  full_name='Bsii.SolarFocus.Protobuf.DataResponseDto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='Bsii.SolarFocus.Protobuf.DataResponseDto.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_objects_metadata', full_name='Bsii.SolarFocus.Protobuf.DataResponseDto.field_objects_metadata', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_metadata', full_name='Bsii.SolarFocus.Protobuf.DataResponseDto.site_metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3283,
  serialized_end=3496,
)

_TAGSIDENTIFIERBASE.fields_by_name['tag_type'].enum_type = _IDENTIFIERTYPES
_TAGSIDENTIFIERBASE.fields_by_name['tag_identifier'].message_type = _TAGIDENTIFIER
_TAGSIDENTIFIERBASE.fields_by_name['virtual_tag_identifier'].message_type = _VIRTUALTAGIDENTIFIER
_TAGSIDENTIFIERBASE.oneofs_by_name['subtype'].fields.append(
  _TAGSIDENTIFIERBASE.fields_by_name['tag_identifier'])
_TAGSIDENTIFIERBASE.fields_by_name['tag_identifier'].containing_oneof = _TAGSIDENTIFIERBASE.oneofs_by_name['subtype']
_TAGSIDENTIFIERBASE.oneofs_by_name['subtype'].fields.append(
  _TAGSIDENTIFIERBASE.fields_by_name['virtual_tag_identifier'])
_TAGSIDENTIFIERBASE.fields_by_name['virtual_tag_identifier'].containing_oneof = _TAGSIDENTIFIERBASE.oneofs_by_name['subtype']
_VIRTUALTAGIDENTIFIER.oneofs_by_name['_field_object'].fields.append(
  _VIRTUALTAGIDENTIFIER.fields_by_name['field_object'])
_VIRTUALTAGIDENTIFIER.fields_by_name['field_object'].containing_oneof = _VIRTUALTAGIDENTIFIER.oneofs_by_name['_field_object']
_VIRTUALMODULEINPUTTAG.fields_by_name['raw_id'].message_type = _TAGSIDENTIFIERBASE
_NUMERICTAGMETADATA.fields_by_name['min_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_NUMERICTAGMETADATA.fields_by_name['max_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_ALARMMETADATA.fields_by_name['severity'].enum_type = _ALARMSEVERITY
_ALARMMETADATA.fields_by_name['category'].enum_type = _ALARMCATEGORY
_ALARMMETADATA.fields_by_name['component_type'].enum_type = _FIELDOBJECTTYPE
_TAGMETADATA.fields_by_name['alaram_metadata'].message_type = _ALARMMETADATA
_TAGMETADATA.fields_by_name['numeric_tag_metadata'].message_type = _NUMERICTAGMETADATA
_TAGMETADATA.fields_by_name['type'].enum_type = _VIRTUALTAGTYPE
_TAGMETADATA.oneofs_by_name['metadata'].fields.append(
  _TAGMETADATA.fields_by_name['alaram_metadata'])
_TAGMETADATA.fields_by_name['alaram_metadata'].containing_oneof = _TAGMETADATA.oneofs_by_name['metadata']
_TAGMETADATA.oneofs_by_name['metadata'].fields.append(
  _TAGMETADATA.fields_by_name['numeric_tag_metadata'])
_TAGMETADATA.fields_by_name['numeric_tag_metadata'].containing_oneof = _TAGMETADATA.oneofs_by_name['metadata']
_VIRTUALDATAMODULE.fields_by_name['calculation_method'].enum_type = _CALCULATIONMETHOD
_VIRTUALDATAMODULE.fields_by_name['sample_frequency'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_VIRTUALDATAMODULE.fields_by_name['input_data'].message_type = _VIRTUALMODULEINPUTTAG
_VIRTUALDATAMODULE.fields_by_name['output_data'].message_type = _TAGMETADATA
_VIRTUALDATAMODULE.fields_by_name['category'].enum_type = _VIRTUALMODULECATEGORY
_VALUEPEROBJECT_DATAENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_VALUEPEROBJECT_DATAENTRY.containing_type = _VALUEPEROBJECT
_VALUEPEROBJECT.fields_by_name['data'].message_type = _VALUEPEROBJECT_DATAENTRY
_VALUEPEROBJECT.fields_by_name['timestamp_utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ALARM.fields_by_name['start_time_utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ALARM.fields_by_name['end_time_utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DATAPOINT.fields_by_name['time_value'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DATAPOINT.fields_by_name['value_per_object'].message_type = _VALUEPEROBJECT
_DATAPOINT.fields_by_name['table'].message_type = _DATAFRAMEDTO
_DATAPOINT.fields_by_name['alarm'].message_type = _ALARM
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['value'])
_DATAPOINT.fields_by_name['value'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['string_value'])
_DATAPOINT.fields_by_name['string_value'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['time_value'])
_DATAPOINT.fields_by_name['time_value'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['value_per_object'])
_DATAPOINT.fields_by_name['value_per_object'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['table'])
_DATAPOINT.fields_by_name['table'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['alarm'])
_DATAPOINT.fields_by_name['alarm'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_ROWDATADTO_VALUEENTRY.fields_by_name['value'].message_type = _DATAPOINT
_ROWDATADTO_VALUEENTRY.containing_type = _ROWDATADTO
_ROWDATADTO.fields_by_name['timestamp_utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ROWDATADTO.fields_by_name['value'].message_type = _ROWDATADTO_VALUEENTRY
_ROWDATADTO.oneofs_by_name['index'].fields.append(
  _ROWDATADTO.fields_by_name['timestamp_utc'])
_ROWDATADTO.fields_by_name['timestamp_utc'].containing_oneof = _ROWDATADTO.oneofs_by_name['index']
_ROWDATADTO.oneofs_by_name['index'].fields.append(
  _ROWDATADTO.fields_by_name['string_index'])
_ROWDATADTO.fields_by_name['string_index'].containing_oneof = _ROWDATADTO.oneofs_by_name['index']
_ROWDATADTO.oneofs_by_name['index'].fields.append(
  _ROWDATADTO.fields_by_name['numeric_index'])
_ROWDATADTO.fields_by_name['numeric_index'].containing_oneof = _ROWDATADTO.oneofs_by_name['index']
_DATAFRAMEDTO.fields_by_name['data'].message_type = _ROWDATADTO
_FIELDOBJECTMETADATA.fields_by_name['type'].enum_type = _FIELDOBJECTTYPE
_SITEMETADATA.oneofs_by_name['_longitude'].fields.append(
  _SITEMETADATA.fields_by_name['longitude'])
_SITEMETADATA.fields_by_name['longitude'].containing_oneof = _SITEMETADATA.oneofs_by_name['_longitude']
_SITEMETADATA.oneofs_by_name['_latitude'].fields.append(
  _SITEMETADATA.fields_by_name['latitude'])
_SITEMETADATA.fields_by_name['latitude'].containing_oneof = _SITEMETADATA.oneofs_by_name['_latitude']
_SITEMETADATA.oneofs_by_name['_altitude'].fields.append(
  _SITEMETADATA.fields_by_name['altitude'])
_SITEMETADATA.fields_by_name['altitude'].containing_oneof = _SITEMETADATA.oneofs_by_name['_altitude']
_SITEMETADATA.oneofs_by_name['_contractor_name'].fields.append(
  _SITEMETADATA.fields_by_name['contractor_name'])
_SITEMETADATA.fields_by_name['contractor_name'].containing_oneof = _SITEMETADATA.oneofs_by_name['_contractor_name']
_SITEMETADATA.oneofs_by_name['_max_power'].fields.append(
  _SITEMETADATA.fields_by_name['max_power'])
_SITEMETADATA.fields_by_name['max_power'].containing_oneof = _SITEMETADATA.oneofs_by_name['_max_power']
_INPUTDATAREQUESTARGS.fields_by_name['start_time_utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INPUTDATAREQUESTARGS.fields_by_name['end_time_utc'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INPUTDATAREQUESTARGS.fields_by_name['module_metadata'].message_type = _VIRTUALDATAMODULE
_DATARESPONSEDTO.fields_by_name['data'].message_type = _DATAFRAMEDTO
_DATARESPONSEDTO.fields_by_name['field_objects_metadata'].message_type = _FIELDOBJECTMETADATA
_DATARESPONSEDTO.fields_by_name['site_metadata'].message_type = _SITEMETADATA
DESCRIPTOR.message_types_by_name['TagsIdentifierBase'] = _TAGSIDENTIFIERBASE
DESCRIPTOR.message_types_by_name['TagIdentifier'] = _TAGIDENTIFIER
DESCRIPTOR.message_types_by_name['VirtualTagIdentifier'] = _VIRTUALTAGIDENTIFIER
DESCRIPTOR.message_types_by_name['VirtualModuleInputTag'] = _VIRTUALMODULEINPUTTAG
DESCRIPTOR.message_types_by_name['NumericTagMetadata'] = _NUMERICTAGMETADATA
DESCRIPTOR.message_types_by_name['AlarmMetadata'] = _ALARMMETADATA
DESCRIPTOR.message_types_by_name['TagMetadata'] = _TAGMETADATA
DESCRIPTOR.message_types_by_name['VirtualDataModule'] = _VIRTUALDATAMODULE
DESCRIPTOR.message_types_by_name['ValuePerObject'] = _VALUEPEROBJECT
DESCRIPTOR.message_types_by_name['Alarm'] = _ALARM
DESCRIPTOR.message_types_by_name['DataPoint'] = _DATAPOINT
DESCRIPTOR.message_types_by_name['RowDataDto'] = _ROWDATADTO
DESCRIPTOR.message_types_by_name['DataFrameDto'] = _DATAFRAMEDTO
DESCRIPTOR.message_types_by_name['FieldObjectMetadata'] = _FIELDOBJECTMETADATA
DESCRIPTOR.message_types_by_name['SiteMetadata'] = _SITEMETADATA
DESCRIPTOR.message_types_by_name['InputDataRequestArgs'] = _INPUTDATAREQUESTARGS
DESCRIPTOR.message_types_by_name['DataResponseDto'] = _DATARESPONSEDTO
DESCRIPTOR.enum_types_by_name['VirtualModuleCategory'] = _VIRTUALMODULECATEGORY
DESCRIPTOR.enum_types_by_name['VirtualTagType'] = _VIRTUALTAGTYPE
DESCRIPTOR.enum_types_by_name['CalculationMethod'] = _CALCULATIONMETHOD
DESCRIPTOR.enum_types_by_name['IdentifierTypes'] = _IDENTIFIERTYPES
DESCRIPTOR.enum_types_by_name['AlarmCategory'] = _ALARMCATEGORY
DESCRIPTOR.enum_types_by_name['AlarmSeverity'] = _ALARMSEVERITY
DESCRIPTOR.enum_types_by_name['FieldObjectType'] = _FIELDOBJECTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TagsIdentifierBase = _reflection.GeneratedProtocolMessageType('TagsIdentifierBase', (_message.Message,), {
  'DESCRIPTOR' : _TAGSIDENTIFIERBASE,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.TagsIdentifierBase)
  })
_sym_db.RegisterMessage(TagsIdentifierBase)

TagIdentifier = _reflection.GeneratedProtocolMessageType('TagIdentifier', (_message.Message,), {
  'DESCRIPTOR' : _TAGIDENTIFIER,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.TagIdentifier)
  })
_sym_db.RegisterMessage(TagIdentifier)

VirtualTagIdentifier = _reflection.GeneratedProtocolMessageType('VirtualTagIdentifier', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALTAGIDENTIFIER,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.VirtualTagIdentifier)
  })
_sym_db.RegisterMessage(VirtualTagIdentifier)

VirtualModuleInputTag = _reflection.GeneratedProtocolMessageType('VirtualModuleInputTag', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALMODULEINPUTTAG,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.VirtualModuleInputTag)
  })
_sym_db.RegisterMessage(VirtualModuleInputTag)

NumericTagMetadata = _reflection.GeneratedProtocolMessageType('NumericTagMetadata', (_message.Message,), {
  'DESCRIPTOR' : _NUMERICTAGMETADATA,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.NumericTagMetadata)
  })
_sym_db.RegisterMessage(NumericTagMetadata)

AlarmMetadata = _reflection.GeneratedProtocolMessageType('AlarmMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ALARMMETADATA,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.AlarmMetadata)
  })
_sym_db.RegisterMessage(AlarmMetadata)

TagMetadata = _reflection.GeneratedProtocolMessageType('TagMetadata', (_message.Message,), {
  'DESCRIPTOR' : _TAGMETADATA,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.TagMetadata)
  })
_sym_db.RegisterMessage(TagMetadata)

VirtualDataModule = _reflection.GeneratedProtocolMessageType('VirtualDataModule', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALDATAMODULE,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.VirtualDataModule)
  })
_sym_db.RegisterMessage(VirtualDataModule)

ValuePerObject = _reflection.GeneratedProtocolMessageType('ValuePerObject', (_message.Message,), {

  'DataEntry' : _reflection.GeneratedProtocolMessageType('DataEntry', (_message.Message,), {
    'DESCRIPTOR' : _VALUEPEROBJECT_DATAENTRY,
    '__module__' : 'vt_pb2'
    # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.ValuePerObject.DataEntry)
    })
  ,
  'DESCRIPTOR' : _VALUEPEROBJECT,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.ValuePerObject)
  })
_sym_db.RegisterMessage(ValuePerObject)
_sym_db.RegisterMessage(ValuePerObject.DataEntry)

Alarm = _reflection.GeneratedProtocolMessageType('Alarm', (_message.Message,), {
  'DESCRIPTOR' : _ALARM,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.Alarm)
  })
_sym_db.RegisterMessage(Alarm)

DataPoint = _reflection.GeneratedProtocolMessageType('DataPoint', (_message.Message,), {
  'DESCRIPTOR' : _DATAPOINT,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.DataPoint)
  })
_sym_db.RegisterMessage(DataPoint)

RowDataDto = _reflection.GeneratedProtocolMessageType('RowDataDto', (_message.Message,), {

  'ValueEntry' : _reflection.GeneratedProtocolMessageType('ValueEntry', (_message.Message,), {
    'DESCRIPTOR' : _ROWDATADTO_VALUEENTRY,
    '__module__' : 'vt_pb2'
    # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.RowDataDto.ValueEntry)
    })
  ,
  'DESCRIPTOR' : _ROWDATADTO,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.RowDataDto)
  })
_sym_db.RegisterMessage(RowDataDto)
_sym_db.RegisterMessage(RowDataDto.ValueEntry)

DataFrameDto = _reflection.GeneratedProtocolMessageType('DataFrameDto', (_message.Message,), {
  'DESCRIPTOR' : _DATAFRAMEDTO,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.DataFrameDto)
  })
_sym_db.RegisterMessage(DataFrameDto)

FieldObjectMetadata = _reflection.GeneratedProtocolMessageType('FieldObjectMetadata', (_message.Message,), {
  'DESCRIPTOR' : _FIELDOBJECTMETADATA,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.FieldObjectMetadata)
  })
_sym_db.RegisterMessage(FieldObjectMetadata)

SiteMetadata = _reflection.GeneratedProtocolMessageType('SiteMetadata', (_message.Message,), {
  'DESCRIPTOR' : _SITEMETADATA,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.SiteMetadata)
  })
_sym_db.RegisterMessage(SiteMetadata)

InputDataRequestArgs = _reflection.GeneratedProtocolMessageType('InputDataRequestArgs', (_message.Message,), {
  'DESCRIPTOR' : _INPUTDATAREQUESTARGS,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.InputDataRequestArgs)
  })
_sym_db.RegisterMessage(InputDataRequestArgs)

DataResponseDto = _reflection.GeneratedProtocolMessageType('DataResponseDto', (_message.Message,), {
  'DESCRIPTOR' : _DATARESPONSEDTO,
  '__module__' : 'vt_pb2'
  # @@protoc_insertion_point(class_scope:Bsii.SolarFocus.Protobuf.DataResponseDto)
  })
_sym_db.RegisterMessage(DataResponseDto)


DESCRIPTOR._options = None
_VALUEPEROBJECT_DATAENTRY._options = None
_ROWDATADTO_VALUEENTRY._options = None

_INPUTDATASERVICE = _descriptor.ServiceDescriptor(
  name='InputDataService',
  full_name='Bsii.SolarFocus.Protobuf.InputDataService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=4196,
  serialized_end=4316,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetData',
    full_name='Bsii.SolarFocus.Protobuf.InputDataService.GetData',
    index=0,
    containing_service=None,
    input_type=_INPUTDATAREQUESTARGS,
    output_type=_DATARESPONSEDTO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INPUTDATASERVICE)

DESCRIPTOR.services_by_name['InputDataService'] = _INPUTDATASERVICE

# @@protoc_insertion_point(module_scope)



#!/usr/bin/python3

from datetime import datetime
import numpy as np

class FieldData(np.ndarray):
     def __array_finalize__(self, obj):
        if obj is None: return
        self.objects_ids = getattr(obj, 'objects_ids', None)
        self.update_time = getattr(obj, 'update_time', None)

     def __new__(cls, data, objects_ids, update_time: datetime = None):
        self = np.asarray(data).view(cls)
        self.objects_ids = np.asarray(objects_ids)
        self.update_time = update_time
        return self
    
     def get_object_id(self, i: int):
         return self.objects_ids[i]

class VTCommandLineArgsBase:
    def __init__(self, metadata_file, execution_url, debug, output_filename, api_access_key, insecure, cert, start_utc, end_utc, field_objects):
        self.metadata_file = metadata_file
        self.execution_url = execution_url
        self.debug = debug
        self.output_filename = output_filename
        self.api_access_key = api_access_key
        self.insecure = insecure
        self.cert = cert
        self.start_utc = start_utc
        self.end_utc = end_utc
        self.field_objects = field_objects



#!/usr/bin/python3
from abc import ABC
from typing import Callable, List, Tuple
import pandas as pd
from sf_virtual_data import utils
from sf_virtual_data.api import vt_pb2, vt_pb2_grpc
from sf_virtual_data.models import VTCommandLineArgsBase
import google.protobuf.json_format as json_format


class VirtualTagsRunner(ABC):
    def __init__(self, metadata_file: str):
        self.metadata = self.get_metadata(metadata_file)

    def validate_res(self, res: pd.DataFrame):
        """
        Verify that result of this virtual trend match the defines outputs
        """
        expected = set([x.name for x in self.metadata.output_data])
        results = set([x for x in res.columns])
        if len(expected) != len(results) or expected != results:
            raise Exception(
                "The calculated results map doesn't match the defined output tags: expected - {0}, received - {1}".format(expected, results))


    def query_solar_focus(self, vtCommandLineArgs: VTCommandLineArgsBase) -> Tuple[pd.DataFrame, vt_pb2.SiteMetadata, List[vt_pb2.FieldObjectMetadata]]:
        query = vt_pb2.InputDataRequestArgs(module_metadata = self.metadata)
        if vtCommandLineArgs.end_utc < vtCommandLineArgs.start_utc:
            raise Exception("Query params error: end time - {0} is smaller than start time - {1}".format(vtCommandLineArgs.end_utc, vtCommandLineArgs.start_utc))
        query.start_time_utc.FromDatetime(vtCommandLineArgs.start_utc)
        query.end_time_utc.FromDatetime(vtCommandLineArgs.end_utc)
        query.field_objects_ids.extend(vtCommandLineArgs.field_objects)
        channel = utils.get_grpc_channel_according_to_args(vtCommandLineArgs)
        client = vt_pb2_grpc.InputDataServiceStub(channel)
        server_res: vt_pb2.DataResponseDto = client.GetData(query, metadata=[('x-api-key', f'{vtCommandLineArgs.api_access_key}')])
        df = utils.convert_to_df(server_res.data)
        return (df, server_res.site_metadata, server_res.field_objects_metadata)



    def execute(self, vtCommandLineArgs: VTCommandLineArgsBase, calc_method: Callable) -> pd.DataFrame:
        """
        This is the executaion call for this VT calculation flow
        """
        (input_data, site_metadata, field_objects_metadata) = self.query_solar_focus(vtCommandLineArgs)
        res = calc_method(start_time_utc = vtCommandLineArgs.start_utc, end_time_utc = vtCommandLineArgs.end_utc,
        data = input_data, site_metadata = site_metadata, field_objects_metadata = field_objects_metadata )
        self.validate_res(res)
        return res


    def get_metadata(self, metadata_file: str) -> vt_pb2.VirtualDataModule:
        with open(metadata_file, 'r', encoding='utf-8') as f:
            message = vt_pb2.VirtualDataModule()
            json_format.Parse(f.read(), message)
            return message




#!/usr/bin/python3
import argparse
from datetime import datetime
import os
import numpy as np
import pandas as pd
import sf_virtual_data.models as models
import grpc
import re
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from sf_virtual_data.api import vt_pb2

timedelta_regex = re.compile(r'((?P<hours>\d{2})):((?P<minutes>\d{2})):((?P<seconds>\d{2}))')
MAX_MESSAGE_LENGTH = 100 * 1024 * 1024
TIME_FORMAT = "%Y-%m-%d %H:%M:%S"

class EnvDefault(argparse.Action):
    def __init__(self, envvar, required=True, default=None, **kwargs):
        if not default and envvar:
            if envvar in os.environ:
                default = os.environ[envvar]
        if required and default:
            required = False
        super(EnvDefault, self).__init__(default=default, required=required,
                                         **kwargs)

    def __call__(self, parser, namespace, values, option_string=None):
        setattr(namespace, self.dest, values)


def get_grpc_channel_according_to_args(args: models.VTCommandLineArgsBase) -> grpc.Channel:
    if args.insecure:
        channel = grpc.insecure_channel(args.execution_url, options = [
        ('grpc.max_send_message_length', MAX_MESSAGE_LENGTH),
        ('grpc.max_receive_message_length', MAX_MESSAGE_LENGTH),
        ])
    else:
        credentials = grpc.ssl_channel_credentials()
        channel = grpc.secure_channel(args.execution_url, credentials,  options = [
        ('grpc.max_send_message_length', MAX_MESSAGE_LENGTH),
        ('grpc.max_receive_message_length', MAX_MESSAGE_LENGTH),
        ])
    return channel


def convert_to_df(dto: vt_pb2.DataFrameDto) -> pd.DataFrame:
    res = pd.DataFrame()
    tag_to_series = {}
    for row_data in dto.data:
        for key, data_point in row_data.value.items():
            series = None
            if key in tag_to_series:
                series = tag_to_series[key]
            else:
                series = pd.Series()
                tag_to_series[key] = series
            ### get value
            data_point_value = None
            if data_point.HasField("value"):
                data_point_value = data_point.value
            if data_point.HasField("string_value"):
                data_point_value = data_point.string_value
            if data_point.HasField("time_value"):
                data_point_value = data_point.time_value
            if data_point.HasField("value_per_object"):
                value_per_object_data = []
                objects_ids = []
                for object_id in data_point.value_per_object.data:
                    value_per_object_data.append(data_point.value_per_object.data[object_id].value)
                    objects_ids.append(object_id)
                data_point_value = models.FieldData(data = value_per_object_data,objects_ids = objects_ids, update_time = data_point.value_per_object.timestamp_utc.ToDatetime())
            if data_point.HasField("table"):
                data_point_value = convert_to_df(data_point.table) # not really implemented, user can't define table as an input
            if data_point.HasField("alarm"):
                data_point_value = data_point.alarm # not really implemented, user can't define alarm as an input
            ### get index
            if row_data.HasField("timestamp_utc"):
                series[row_data.timestamp_utc.ToDatetime()] = data_point_value
            if row_data.HasField("string_index"):
                series[row_data.string_index] = data_point_value
            if row_data.HasField("numeric_index"):
                series[row_data.numeric_index] = data_point_value

    for key, series in tag_to_series.items():
        res[key] = series
    return res


def convert_to_dto(df: pd.DataFrame) -> vt_pb2.DataFrameDto:
    res = vt_pb2.DataFrameDto()
    for index, row in df.iterrows():
        row_data = res.data.add()
        index_type = type(index)
        if index_type is str:
            row_data.string_index = index
        if index_type is float or index_type is int :
            row_data.numeric_index = index
        if index_type is google_dot_protobuf_dot_timestamp__pb2.Timestamp:
            row_data.timestamp_utc = index.ToDatetime()
        if index_type is pd.Timestamp:
            timestamp =google_dot_protobuf_dot_timestamp__pb2.Timestamp()
            google_dot_protobuf_dot_timestamp__pb2.Timestamp.FromDatetime(timestamp, dt = index.to_pydatetime())
            row_data.timestamp_utc.CopyFrom(timestamp)
        if index_type is datetime:
            row_data.timestamp_utc = index
        for key, value in row.items():
            data_point = row_data.value[key]
            value_type = type(value)
            if value_type is float:
                data_point.value = value
            if value_type is str:
                data_point.string_value = value
            if value_type is datetime:
                data_point.time_value = value
            if value_type is models.FieldData:
                i = 0
                for val in value:
                    data_point.value_per_object.data[value.get_object_id(i)].value = val
                    i = i + 1
            if value_type is vt_pb2.DataFrameDto:
                data_point.table = value
            if value_type is vt_pb2.Alarm:
                data_point.alarm = value
    return res


def parse_input(cmd_line_args) -> models.VTCommandLineArgsBase:
    parser = argparse.ArgumentParser(
        description='Input parameters to run virtual data module')
    parser.add_argument('--api-access-key',
                        action=EnvDefault,
                        envvar='VT_API_KEY',
                        dest='api_access_key',
                        help='virtual trends api aceess key')
    parser.add_argument('--insecure', action='store_true',
                        dest='insecure',
                        help='do not verfiy https certificate - used for SF execution')
    parser.add_argument('--cert', action='store',
                        dest='cert', default='cert.pem',
                        help='path to root CA relative to entry point file')
    parser.add_argument('--execution-url', dest='execution_url',
                        action='store', default='solarfocus.bseinc.com')
    parser.add_argument('--debug', dest='debug', action='store_true')
    parser.add_argument('--metadata-file', dest='metadata_file',
                        action='store', default='metadata.json')
    parser.add_argument('--output-filename', action='store', required='--debug' not in cmd_line_args and '--metadata' not in cmd_line_args,
                        dest='output_filename',
                        help='Output filename to extract')
    parser.add_argument('--field-objects', action='store', default='',
                        dest='field_objects',
                        help='field objects ids list - can be given by ids seperated by comma (e.g. "1,2,3,4") or by range (e.g. "1-4")')
    parser.add_argument('--start-utc', action='store', required='--metadata' not in cmd_line_args,
                        dest='start',
                        help='Start time of the query in UTC, format YYYY-MM-DD hh:mm:ss')
    parser.add_argument('--end-utc', action='store', required='--metadata' not in cmd_line_args,
                        dest='end',
                        help='End time of the query in UTC, format YYYY-MM-DD hh:mm:ss')
    args = parser.parse_known_args(cmd_line_args)
    known_args = args[0]
    execution_url = known_args.execution_url
    debug = known_args.debug if known_args.debug is not None else False
    insecure = known_args.insecure if known_args.insecure is not None else False
    metadata_file = known_args.metadata_file
    field_objects = list()
    print(known_args.field_objects)
    if known_args.field_objects != "":
        if "-" in known_args.field_objects:
            before, after = known_args.field_objects.split('-')
            field_objects = list(range(int(before), int(after)+1))
        else:
            field_objects = list(map(lambda x: int(x), known_args.field_objects.split(',')))
    start_utc = datetime.strptime(known_args.start, TIME_FORMAT)
    end_utc = datetime.strptime(known_args.end, TIME_FORMAT)
    return models.VTCommandLineArgsBase(metadata_file, execution_url, debug,
                             known_args.output_filename, known_args.api_access_key, insecure, known_args.cert, start_utc, end_utc, field_objects)



#!/usr/bin/python3
from fileinput import filename
import os,sys
import zipfile

from sf_virtual_data.api.vt_pb2 import  TABLES
currentdir = os.path.dirname(os.path.realpath(__file__))
parentdir = os.path.dirname(currentdir)
sys.path.append(parentdir)
import pandas as pd
from sys import argv
from sf_virtual_data import utils
from sf_virtual_data.virtual_tags_runner import VirtualTagsRunner
from user_calculation import calculate as user_calc
from user_calculation import debug as user_debug

def main(cmd_line_args=argv[1:]) -> pd.DataFrame:
    base_cmd_line_args  = utils.parse_input(cmd_line_args)
    vt = VirtualTagsRunner(base_cmd_line_args.metadata_file)
    res = vt.execute(base_cmd_line_args, user_calc)
    tagTimeSeriesData = utils.convert_to_dto(res)
    if not base_cmd_line_args.debug:
        filename = base_cmd_line_args.output_filename
        if vt.metadata.category == TABLES :
            with zipfile.ZipFile(filename, 'w') as myzip:
                print("writing zip file of tables csv's")
                for (columnName, columnData) in res.iteritems():
                    csv_name = columnName + ".csv"
                    columnData.iloc[0].to_csv(csv_name)
                    myzip.write(csv_name)
        else:
            with open(filename, 'wb') as bin_file:
                bin_text = tagTimeSeriesData.SerializeToString()
                bin_file.write(bin_text)
    else:
        user_debug(res)
        
    return res


if __name__ == "__main__":
    """
    Example of script run:  python virtual_trend_entry_point.py --start-utc "2020-10-07 02:00:00" --end-utc "2020-10-07 16:00:00" --debug --api-access-key "<your_api_access_key>"
    or run with IDE run-time args  ["--start-utc","2020-10-07 02:00:00", "--end-utc", "2020-10-07 16:00:00", "--debug", "--api-access-key", "<your_api_access_key>"]
    """
    main()
